@@ -72,24 +72,6 @@ class HardwareType(Enum):
         return self._display
 
 
-class ThermostatMode(Enum):
-    HEAT = "HEAT"
-    COOL = "COOL"
-    FAN = "FAN"
-
-
-class ThermostatFanSpeed(Enum):
-    LOW = "LOW"
-    MEDIUM = "MEDIUM"
-    HIGH = "HIGH"
-    AUTO = "AUTO"
-
-
-class ThermostatTemperatureUnit(Enum):
-    CELSIUS = "CELSIUS"
-    FAHRENHEIT = "FAHRENHEIT"
-
-
 @dataclass
 class SwitchBeeBaseDevice(ABC):
     id: int
@@ -186,14 +168,14 @@ class SwitchBeeBaseTimer(ABC):
 @dataclass
 class SwitchBeeBaseThermostat(ABC):
 
-    modes: List[ThermostatMode]
-    unit: ThermostatTemperatureUnit 
-    mode: ThermostatMode = field(init=False)
-    fan: ThermostatFanSpeed = field(init=False)
+    modes: List[str]
+    unit: str
+    mode: str = field(init=False)
+    fan: str = field(init=False)
     target_temperature: int = field(init=False)
     temperature: int = field(init=False)
-    max_temp: int = 31
-    min_temp: int = 16
+    max_temperature: int = 31
+    min_temperature: int = 16
 
 
 @dataclass
